# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
import django.utils.timezone
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='CustomContent',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('created', django_extensions.db.fields.CreationDateTimeField(default=django.utils.timezone.now, verbose_name='created', editable=False, blank=True)),
                ('modified', django_extensions.db.fields.ModificationDateTimeField(default=django.utils.timezone.now, verbose_name='modified', editable=False, blank=True)),
                ('title', models.CharField(max_length=255, blank=True)),
                ('path', models.CharField(help_text=b'URL you want to use, python regular experssion, or constant "all"', max_length=255, blank=True)),
                ('css', models.TextField(blank=True)),
                ('javascript', models.TextField(blank=True)),
                ('active', models.BooleanField(default=True)),
                ('exact_match', models.BooleanField(default=True, help_text=b'Used when you want to add a code snippet to a specific page only.')),
                ('partial_match', models.BooleanField(default=False, help_text=b'Used when you want to add a code snippet to a lot of pages based on a regex.')),
                ('header', models.BooleanField(default=False, help_text=b'Set javascript to be in the head. Otherwise it will be in the footer')),
            ],
            options={
                'ordering': ('-modified', '-created'),
                'abstract': False,
                'get_latest_by': 'modified',
            },
        ),
    ]



import re
from django.db import models
from django.core.exceptions import ValidationError
from django.utils.encoding import python_2_unicode_compatible

from django_extensions.db.models import TimeStampedModel


@python_2_unicode_compatible
class CustomContent(TimeStampedModel):
    title = models.CharField(max_length=255, blank=True)
    path = models.CharField(
        max_length=255, blank=True,
        help_text=('URL you want to use, python regular experssion, or '
                   'constant "all"'))
    css = models.TextField(blank=True)
    javascript = models.TextField(blank=True)
    active = models.BooleanField(default=True)
    exact_match = models.BooleanField(
        default=True, help_text=('Used when you want to add a code snippet to'
                                 ' a specific page only.'))
    partial_match = models.BooleanField(
        default=False, help_text=('Used when you want to add a code snippet to'
                                  ' a lot of pages based on a regex.'))
    header = models.BooleanField(
        default=False, help_text=('Set javascript to be in the head.'
                                  ' Otherwise it will be in the footer'))

    def __str__(self):
        return u'{} - {}'.format(self.title, self.path)

    def get_absolute_url(self):
        return self.path

    def clean(self):
        if self.exact_match and self.partial_match:
            raise ValidationError('You must set Exact match or Partial match '
                                  'not both.')

        if self.partial_match:
            try:
                re.compile(self.path)
            except re.error as ex:
                raise ValidationError(str(ex))



import re

from djthirdparty.models import CustomContent


__all__ = ['custom_content']


def set_header_footer_content(collection, js):
    if js.header:
        collection['header'].append(js)
    else:
        collection['footer'].append(js)


def fetch_objects():
    all_objects = CustomContent.objects.filter(active=True)
    url_shortcuts = ['all']
    all_urls = {'header': [], 'footer': []}
    exact_urls = {'header': [], 'footer': []}
    partial_urls = {'header': [], 'footer': []}

    for obj in all_objects.iterator():
        in_shortcut = obj.path in url_shortcuts

        if obj.path == 'all':
            set_header_footer_content(all_urls, obj)
        elif obj.exact_match and (not in_shortcut) and not obj.partial_match:
            set_header_footer_content(exact_urls, obj)
        elif obj.partial_match and (not in_shortcut) and not obj.exact_match:
            set_header_footer_content(partial_urls, obj)

    return {
        'all_urls': all_urls,'exact_urls': exact_urls,
        'partial_urls': partial_urls}


def final_content(location, request, custom_js):
    final_javascript = ""
    final_javascript += "".join(
        [js.javascript for js in custom_js['all_urls'][location]])
    final_javascript += "".join(
        [js.javascript for js in custom_js['exact_urls'][location]
            if js.path == request.path])
    final_javascript += "".join(
        [js.javascript for js in custom_js['partial_urls'][location]
            if re.compile(js.path).search(request.path)])
    return final_javascript


def custom_content(request):
    if not request:
        return {}
    custom = fetch_objects()

    return {'custom_javascript_footer': final_content('footer',
                                                      request, custom),
            'custom_javascript_header': final_content('header',
                                                      request, custom)}



from django.contrib import admin

from .models import CustomContent


class CustomContentAdmin(admin.ModelAdmin):
    list_display = ('title', 'path', 'active')
    list_filter = ('active', 'exact_match', 'partial_match')
    fieldsets = (
        (None, {'fields': ('title', 'path',)}),
        ('Settings', {'fields': (
            'active', 'exact_match', 'partial_match', 'header',)}),
        ('Content', {'fields': ('javascript', 'css')})
    )

    def activate(self, request, qs):
        qs.update(active=True)
    activate.short_description = 'Activate selected javascript'

    def deactivate(self, request, qs):
        qs.update(active=False)
    deactivate.short_description = 'Deactivate selected javascript'

    actions = (activate, deactivate)


admin.site.register(CustomContent, CustomContentAdmin)



#!/usr/bin/env python

from setuptools import setup

setup(
    name='django-third-party',
    version='0.1.0',
    description='Add third party scripts and css to specific paths via db.',
    author='Buddy Lindsey',
    author_email='buddy@buddylindsey.com',
    url='https://github.com/buddylindsey/django-third-party',
    packages=[
        'djthirdparty', 'djthirdparty.migrations'],
    install_requires=[
        'Django>=1.8', 'six', 'django_extensions'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.8',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP :: Site Management'],
)
